@@ -36,7 +36,7 @@ class Decoder_FEN():
         squeezed = re.sub('11', '2', filtered)
         return squeezed
 
-    def _simple_validator(self, squares) -> None:
+    def _simple_validator(self, squares):
         ''' ensures that model:
             - found only one white king
             - found only one black king
@@ -57,21 +57,17 @@ class Decoder_FEN():
             if square != 'empty':
                 figures +=1
         print(f'figures:{figures}')
-        print(f'len figures:{len(figures)}')
         print(f'kb:{count_king_black}')
         print(f'kw:{count_king_white}')
         if ((count_king_black != 1) or (count_king_white != 1) or ((figures) > 32)):
-            raise InvalidChessboardLayout()
-
+            return 'invalid'
 
 
 
 
 
     def fen_decode(self, squares, end_of_row='/', black_view=False) -> str:
-        try:
-            self._simple_validator(squares)
-        except Exception as E:
+        if (self._simple_validator(squares) == 'invalid'):
             return 'Model can\'t find valid chessboard layout'
         long_fen = ''
         for i, square in enumerate(squares):
